==> kubernetes-model-1.0.63-sources.jar: annotations/io/fabric8/kubernetes/api/model/DoneableDeprecatedDownwardAPIVolumeFile.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Function;

public class DoneableDeprecatedDownwardAPIVolumeFile extends DeprecatedDownwardAPIVolumeFileFluentImpl<DoneableDeprecatedDownwardAPIVolumeFile> implements Doneable<DeprecatedDownwardAPIVolumeFile>{

    private final DeprecatedDownwardAPIVolumeFileBuilder builder;
    private final Function<DeprecatedDownwardAPIVolumeFile,DeprecatedDownwardAPIVolumeFile> function;

    public DoneableDeprecatedDownwardAPIVolumeFile(Function<DeprecatedDownwardAPIVolumeFile,DeprecatedDownwardAPIVolumeFile> function){
            super();this.builder=new DeprecatedDownwardAPIVolumeFileBuilder(this);this.function=function;
    }
    public DoneableDeprecatedDownwardAPIVolumeFile(DeprecatedDownwardAPIVolumeFile item,Function<DeprecatedDownwardAPIVolumeFile,DeprecatedDownwardAPIVolumeFile> function){
            super(item);this.builder=new DeprecatedDownwardAPIVolumeFileBuilder(this, item);this.function=function;
    }
    public DoneableDeprecatedDownwardAPIVolumeFile(DeprecatedDownwardAPIVolumeFile item){
            super(item);this.builder=new DeprecatedDownwardAPIVolumeFileBuilder(this, item);this.function=new Function<DeprecatedDownwardAPIVolumeFile, DeprecatedDownwardAPIVolumeFile>() {
    public DeprecatedDownwardAPIVolumeFile apply(DeprecatedDownwardAPIVolumeFile item) {
        return item;
    }
}
;
    }

    public DeprecatedDownwardAPIVolumeFile done(){
             return function.apply(builder.build());
    }




}

==> kubernetes-model-1.0.77-sources.jar: annotations/io/fabric8/kubernetes/api/model/DoneableDeprecatedDownwardAPIVolumeFile.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Function;

public class DoneableDeprecatedDownwardAPIVolumeFile extends DeprecatedDownwardAPIVolumeFileFluentImpl<DoneableDeprecatedDownwardAPIVolumeFile> implements Doneable<DeprecatedDownwardAPIVolumeFile>{

    private final DeprecatedDownwardAPIVolumeFileBuilder builder;
    private final io.fabric8.kubernetes.api.builder.Function<DeprecatedDownwardAPIVolumeFile,DeprecatedDownwardAPIVolumeFile> function;

    public DoneableDeprecatedDownwardAPIVolumeFile(io.fabric8.kubernetes.api.builder.Function<DeprecatedDownwardAPIVolumeFile,DeprecatedDownwardAPIVolumeFile> function){
            super();this.builder=new DeprecatedDownwardAPIVolumeFileBuilder(this);this.function=function;
    }
    public DoneableDeprecatedDownwardAPIVolumeFile(DeprecatedDownwardAPIVolumeFile item,io.fabric8.kubernetes.api.builder.Function<DeprecatedDownwardAPIVolumeFile,DeprecatedDownwardAPIVolumeFile> function){
            super(item);this.builder=new DeprecatedDownwardAPIVolumeFileBuilder(this, item);this.function=function;
    }
    public DoneableDeprecatedDownwardAPIVolumeFile(DeprecatedDownwardAPIVolumeFile item){
            super(item);this.builder=new DeprecatedDownwardAPIVolumeFileBuilder(this, item);this.function=new Function<DeprecatedDownwardAPIVolumeFile, DeprecatedDownwardAPIVolumeFile>() {
    public DeprecatedDownwardAPIVolumeFile apply(DeprecatedDownwardAPIVolumeFile item) {
        return item;
    }
}
;
    }

    public DeprecatedDownwardAPIVolumeFile done(){
             return function.apply(builder.build());
    }




}
